aboutsummaryrefslogtreecommitdiffstats
path: root/ui
diff options
context:
space:
mode:
Diffstat (limited to 'ui')
-rw-r--r--ui/ui.core.js13
1 files changed, 4 insertions, 9 deletions
diff --git a/ui/ui.core.js b/ui/ui.core.js
index f9c8a1486..7bafe917a 100644
--- a/ui/ui.core.js
+++ b/ui/ui.core.js
@@ -118,19 +118,14 @@ $.ui = {
return has;
},
- isOverHeight: function(y, top, height) {
- //Determines when y coordinate is over "b" element height
- return (y > top) && (y < (top + height));
- },
-
- isOverWidth: function(x, left, width) {
- //Determines when x coordinate is over "b" element width
- return (x > left) && (x < (left + width));
+ isOverAxis: function(x, reference, size) {
+ //Determines when x coordinate is over "b" element axis
+ return (x > reference) && (x < (reference + size));
},
isOver: function(y, x, top, left, height, width) {
//Determines when x, y coordinates is over "b" element
- return $.ui.isOverHeight(y, top, height) && $.ui.isOverWidth(x, left, width);
+ return $.ui.isOverAxis(y, top, height) && $.ui.isOverAxis(x, left, width);
}
};